################################################################################
## data_exploratory_analysis.r
## exploratory analysis for raw or normalized data
## 2015-08-10  fgarcia@cipf.es
################################################################################

date ()
Sys.info ()[c("nodename", "user")]
commandArgs ()
rm (list = ls ())
R.version.string #"R version 3.2.1 (2015-06-18)""




###FUNCTIONS
################################################################################

source ("function_arbol_2.r")
source ("function_pcaGenes_2.r")




###DATA
################################################################################

datos <- read.table("datos.txt", sep = "\t", as.is = T)
head(datos)
dim(datos)

#estos datos incluyen doce muestras pertenecientes a 6 individuos (una con tratamiento y otra sin tratamiento)
#genero un dataframe que llamare sinfo con las varias variables que utilizare para colorear las muestras: 
pair   <- c(1,1,2,2,3,3,4,4,5,5,6,6)   #esta variable distingue las parejas de muestras correspondientes al mismo sujeto
group     <- rep(c("T","none"), 6)     #esta variable diferencia muestras con y sin tratamiento
samplename <- colnames(datos)
sinfo <- as.data.frame(cbind(samplename, pair, group), as.is = T)
sinfo


#ahora asigno colores a las variables anteriores:
char.pair <- as.character (sinfo[,"pair"])
tan <- unique (char.pair)
micolor <- rainbow (length (tan))
names (micolor) <- tan
sinfo$color.pair <- micolor[char.pair]

char.group <- as.character (sinfo[,"group"])
tan <- unique (char.group)
micolor <- rainbow (length (tan))
names (micolor) <- tan
sinfo$color.group <- micolor[char.group]

sinfo




###CLUSTERING, pair   (coloreo las muestras segun el sujeto, me lo indica la variable "pair")
##################################

#asigno tamanyo para la representacion grafica del clustering
x.por <- 1
y.por <- 1

### cluster with correlation distance
correlacion <- cor (datos)
distancia <- as.dist ((1 - correlacion) / 2)
hc <- hclust (distancia)
table (hc$labels ==  sinfo$samplename) #ok esta en orden
##
hc$clase <- sinfo$pair  ##COLOREAMOS SEGUN LA VARIABLE pair
##
png (filename ="cluster_corelationd_pair.png",   width = 480 * x.por, height = 480 * y.por)
arbol (cluster = hc, main = "Clustering. Correlation distance ")
dev.off ()

### cluster with euclidean distance 
distancia <- dist (t (datos), method = "euclidean") #dist trabaja por filas
he <- hclust (distancia)
table (he$labels == sinfo$samplename) #ok esta en orden
##
he$clase <- sinfo$pair  ##COLOREAMOS SEGUN LA VARIABLE pair
##
png (filename = "cluster_euclideand_pair.png", width = 480 * x.por, height = 480 * y.por)
arbol (cluster = he, main = "Clustering. Euclidean  distance")
dev.off ()


###CLUSTERING, group
##################################

x.por <- 1
y.por <- 1

### cluster with correlation distance
correlacion <- cor (datos)
distancia <- as.dist ((1 - correlacion) / 2)
hc <- hclust (distancia)
table (hc$labels ==  sinfo$samplename) #ok esta en orden
##
hc$clase <- sinfo$group  ##COLOREAMOS SEGUN LA VARIABLE group
##
png (filename = "normdata_cluster_corelationd_group.png", width = 480 * x.por, height = 480 * y.por)
arbol (cluster = hc, main = "Clustering. Correlation distance ")
dev.off ()

### cluster with euclidean distance 
distancia <- dist (t (datos), method = "euclidean") #dist trabaja por filas
he <- hclust (distancia)
table (he$labels == sinfo$samplename) #ok esta en orden
##
he$clase <- sinfo$group  ##COLOREAMOS SEGUN LA VARIABLE group
##
png (filename ="cluster_euclideand_group.png",  width = 480 * x.por, height = 480 * y.por)
arbol (cluster = he, main = "Clustering. Euclidean  distance")
dev.off ()



###PCAs, pair
##################################

x.por <- 2
y.por <- 1

system.time (mi.pca <- pcaGenes (datos))

names (mi.pca)
sapply (mi.pca, dim)
table (colnames (mi.pca$Xoff) == sinfo$samplename) ##revisar los nombres

png (filename = "pca_pair.png",     width = 480 * x.por, height = 480 * y.por)
plot.pca.genes (mi.pca, main = "PCA plot", col = sinfo$color.pair, col.class = sinfo$pair, pch = ".")
dev.off ()


###PCAs, group
##################################


x.por <- 2
y.por <- 1

system.time (mi.pca <- pcaGenes (datos))

names (mi.pca)
sapply (mi.pca, dim)
table (colnames (mi.pca$Xoff) == sinfo$samplename) ##revisar los nombres

png (filename = "pca_group.png", width = 480 * x.por, height = 480 * y.por)
plot.pca.genes (mi.pca, main = "PCA plot", col = sinfo$color.group, col.class = sinfo$group, pch = ".")
dev.off ()




###EXIT
sessionInfo ()
q ("no")
